import re  # 导入正则表达式模块，用于文本处理
import json  # 导入json模块，用于读取和解析JSON格式的数据
from sklearn.model_selection import train_test_split  # 导入train_test_split用于分割数据集

# 打开并读取recipes.json文件，加载数据
with open('recipes.json') as f:
    data = json.load(f)  # 使用json.load()将文件内容转换为Python对象（通常是字典或列表）

# 定义一个函数，将处理后的数据保存为文本文件
def build_text_files(data_json, dest_path):
    f = open(dest_path, 'w')  # 打开目标文件（以写入模式'w'打开）
    data = ''  # 用于存储所有的食谱做法文本
    for texts in data_json:  # 遍历每一个食谱数据
        summary = str(texts['Instructions']).strip()  # 提取做法部分并去除前后空格
        summary = re.sub(r"\s", " ", summary)  # 使用正则表达式替换所有空白字符为单一空格
        data += summary + "  "  # 将处理后的做法添加到data字符串中，每条食谱之间用两个空格分隔
    f.write(data)  # 将拼接好的文本数据写入目标文件

# 使用train_test_split函数将数据分割为训练集和测试集
train, test = train_test_split(data, test_size=0.15)  # 设定测试集占15%，剩下的85%为训练集

# 将训练集和测试集分别保存到文本文件中
build_text_files(train, 'train_dataset.txt')  # 将训练集数据保存到train_dataset.txt文件
build_text_files(test, 'test_dataset.txt')    # 将测试集数据保存到test_dataset.txt文件

# 打印训练集和测试集的长度（即样本数量）
print("Train dataset length: " + str(len(train)))  # 输出训练集的大小
print("Test dataset length: " + str(len(test)))    # 输出测试集的大小

# 输出示例：
# Train dataset length: 10361
# Test dataset length: 1829
